@@ -41,10 +41,10 @@ class Case(object):
     def __init__(
         self,
         index=False,
-        type="CF",
-        county="tulsa",
-        year="2019",
-        number=1,
+        type=None,
+        county=None,
+        year=None,
+        number=None,
         cmid=False,
         **kwargs,
     ):
@@ -52,22 +52,24 @@ class Case(object):
             index_parts = index.split("-")
             len_index_parts = len(index_parts)
             if len_index_parts == 4:
-                self.county, self.type, self.year, number_str = index_parts
-                self.number = int(number_str)
+                self.county, self.type, self.year, self.number = index_parts
             elif len_index_parts == 3:
-                self.county, self.type, number_str = index_parts
-                self.number = int(number_str)
+                self.county, self.type, self.number = index_parts
             elif len_index_parts == 2:
-                self.county, number_str = index_parts
-                self.number = int(number_str)
-                self.type = "IN"
+                self.county, self.number = index_parts
+                # self.type = "IN"
         else:
             self.county = county
             self.year = year
-            self.number = int(number)
-            self.type = "IN" if county == "appellate" else type
+            self.number = number
+            self.type = type
+            # self.type = "IN" if county == "appellate" and type==None else type
+
+        if hasattr(self, "type"):
+            self.cmid = self.type == "cmid"
+        else:
+            self.cmid = False
 
-        self.cmid = self.type == "cmid"
         self.source = kwargs["source"] if "source" in kwargs else False
 
         if "text" in kwargs:
@@ -87,21 +89,31 @@ class Case(object):
 
     @property
     def oscn_number(self):
-        if self.county == "appellate":
-            return f"{self.number}"
-        else:
-            return f"{self.type}-{self.year}-{self.number}"
+        key_names = ["type", "year", "number"]
+        number_parts = []
+        for ky in key_names:
+            if hasattr(self, ky):
+                ky_val = getattr(self, ky)
+                if ky_val:
+                    number_parts.append(str(getattr(self, ky)))
+        return "-".join(number_parts)
 
     @property
     def index(self):
         return f"{self.county}-{self.oscn_number}"
 
+    @property
+    def inner_path(self):
+        path_parts = []
+        key_names = ["county", "type", "year"]
+        for ky in key_names:
+            if hasattr(self, ky):
+                path_parts.append(getattr(self, ky))
+        return "/".join(path_parts)
+
     @property
     def path(self):
-        if self.county == "appellate":
-            return f"{self.directory}/{self.county}"
-        else:
-            return f"{self.directory}/{self.county}/{self.type}/{self.year}"
+        return f"{self.directory}/{self.inner_path}"
 
     @property
     def file_name(self):
@@ -109,10 +121,7 @@ class Case(object):
 
     @property
     def s3_key(self):
-        if self.county == "appellate":
-            return f"{self.county}/{self.number}.zip"
-        else:
-            return f"{self.county}/{self.type}/{self.year}/{self.number}.zip"
+        return f"{self.inner_path}/{self.number}.zip"
 
     def save(self, **kwargs):
         case_data = {
@@ -196,6 +205,7 @@ class Case(object):
                 return self._request(attempts_left=attempts_left - 1)
             else:
                 raise ConnectionError
+
         if self._valid_response(response):
             self.valid = True
             self.source = f"{response.url}"
@@ -285,7 +295,6 @@ class CaseList(object):
         return next(self.all_cases)
 
     def _passes_filters(self, case):
-
         def does_it_pass(filter):
             target, test = filter
             target_value = getattr(case, target)
